==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/kusto/kotlin/outputs/GetReadOnlyFollowingDatabaseResult.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.kusto.kotlin.outputs

import kotlin.String
import kotlin.Suppress

/**
 * Class representing a read only following database.
 * @property attachedDatabaseConfigurationName The name of the attached database configuration cluster
 * @property databaseShareOrigin The origin of the following setup.
 * @property hotCachePeriod The time the data should be kept in cache for fast queries in TimeSpan.
 * @property id Fully qualified resource ID for the resource. Ex - /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/{resourceProviderNamespace}/{resourceType}/{resourceName}
 * @property kind Kind of the database
 * Expected value is 'ReadOnlyFollowing'.
 * @property leaderClusterResourceId The name of the leader cluster
 * @property location Resource location.
 * @property name The name of the resource
 * @property originalDatabaseName The original database name, before databaseNameOverride or databaseNamePrefix where applied.
 * @property principalsModificationKind The principals modification kind of the database
 * @property provisioningState The provisioned state of the resource.
 * @property softDeletePeriod The time the data should be kept before it stops being accessible to queries in TimeSpan.
 * @property statistics The statistics of the database.
 * @property tableLevelSharingProperties Table level sharing specifications
 * @property type The type of the resource. E.g. "Microsoft.Compute/virtualMachines" or "Microsoft.Storage/storageAccounts"
 */
public data class GetReadOnlyFollowingDatabaseResult(
    public val attachedDatabaseConfigurationName: String,
    public val databaseShareOrigin: String,
    public val hotCachePeriod: String? = null,
    public val id: String,
    public val kind: String,
    public val leaderClusterResourceId: String,
    public val location: String? = null,
    public val name: String,
    public val originalDatabaseName: String,
    public val principalsModificationKind: String,
    public val provisioningState: String,
    public val softDeletePeriod: String,
    public val statistics: DatabaseStatisticsResponse,
    public val tableLevelSharingProperties: TableLevelSharingPropertiesResponse,
    public val type: String,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.azurenative.kusto.outputs.GetReadOnlyFollowingDatabaseResult):
            GetReadOnlyFollowingDatabaseResult = GetReadOnlyFollowingDatabaseResult(
            attachedDatabaseConfigurationName = javaType.attachedDatabaseConfigurationName(),
            databaseShareOrigin = javaType.databaseShareOrigin(),
            hotCachePeriod = javaType.hotCachePeriod().map({ args0 -> args0 }).orElse(null),
            id = javaType.id(),
            kind = javaType.kind(),
            leaderClusterResourceId = javaType.leaderClusterResourceId(),
            location = javaType.location().map({ args0 -> args0 }).orElse(null),
            name = javaType.name(),
            originalDatabaseName = javaType.originalDatabaseName(),
            principalsModificationKind = javaType.principalsModificationKind(),
            provisioningState = javaType.provisioningState(),
            softDeletePeriod = javaType.softDeletePeriod(),
            statistics = javaType.statistics().let({ args0 ->
                com.pulumi.azurenative.kusto.kotlin.outputs.DatabaseStatisticsResponse.Companion.toKotlin(args0)
            }),
            tableLevelSharingProperties = javaType.tableLevelSharingProperties().let({ args0 ->
                com.pulumi.azurenative.kusto.kotlin.outputs.TableLevelSharingPropertiesResponse.Companion.toKotlin(args0)
            }),
            type = javaType.type(),
        )
    }
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/kusto/kotlin/outputs/GetReadOnlyFollowingDatabaseResult.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.kusto.kotlin.outputs

import kotlin.String
import kotlin.Suppress

/**
 * Class representing a read only following database.
 * @property attachedDatabaseConfigurationName The name of the attached database configuration cluster
 * @property databaseShareOrigin The origin of the following setup.
 * @property hotCachePeriod The time the data should be kept in cache for fast queries in TimeSpan.
 * @property id Fully qualified resource ID for the resource. Ex - /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/{resourceProviderNamespace}/{resourceType}/{resourceName}
 * @property kind Kind of the database
 * Expected value is 'ReadOnlyFollowing'.
 * @property leaderClusterResourceId The name of the leader cluster
 * @property location Resource location.
 * @property name The name of the resource
 * @property originalDatabaseName The original database name, before databaseNameOverride or databaseNamePrefix where applied.
 * @property principalsModificationKind The principals modification kind of the database
 * @property provisioningState The provisioned state of the resource.
 * @property softDeletePeriod The time the data should be kept before it stops being accessible to queries in TimeSpan.
 * @property statistics The statistics of the database.
 * @property tableLevelSharingProperties Table level sharing specifications
 * @property type The type of the resource. E.g. "Microsoft.Compute/virtualMachines" or "Microsoft.Storage/storageAccounts"
 */
public data class GetReadOnlyFollowingDatabaseResult(
    public val attachedDatabaseConfigurationName: String,
    public val databaseShareOrigin: String,
    public val hotCachePeriod: String? = null,
    public val id: String,
    public val kind: String,
    public val leaderClusterResourceId: String,
    public val location: String? = null,
    public val name: String,
    public val originalDatabaseName: String,
    public val principalsModificationKind: String,
    public val provisioningState: String,
    public val softDeletePeriod: String,
    public val statistics: DatabaseStatisticsResponse,
    public val tableLevelSharingProperties: TableLevelSharingPropertiesResponse,
    public val type: String,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.kusto.outputs.GetReadOnlyFollowingDatabaseResult): GetReadOnlyFollowingDatabaseResult = GetReadOnlyFollowingDatabaseResult(
            attachedDatabaseConfigurationName = javaType.attachedDatabaseConfigurationName(),
            databaseShareOrigin = javaType.databaseShareOrigin(),
            hotCachePeriod = javaType.hotCachePeriod().map({ args0 -> args0 }).orElse(null),
            id = javaType.id(),
            kind = javaType.kind(),
            leaderClusterResourceId = javaType.leaderClusterResourceId(),
            location = javaType.location().map({ args0 -> args0 }).orElse(null),
            name = javaType.name(),
            originalDatabaseName = javaType.originalDatabaseName(),
            principalsModificationKind = javaType.principalsModificationKind(),
            provisioningState = javaType.provisioningState(),
            softDeletePeriod = javaType.softDeletePeriod(),
            statistics = javaType.statistics().let({ args0 ->
                com.pulumi.azurenative.kusto.kotlin.outputs.DatabaseStatisticsResponse.Companion.toKotlin(args0)
            }),
            tableLevelSharingProperties = javaType.tableLevelSharingProperties().let({ args0 ->
                com.pulumi.azurenative.kusto.kotlin.outputs.TableLevelSharingPropertiesResponse.Companion.toKotlin(args0)
            }),
            type = javaType.type(),
        )
    }
}
